Enum ssh_key::Fingerprint
source · #[non_exhaustive]
pub enum Fingerprint {
Sha256([u8; 32]),
Sha512([u8; 64]),
}Expand description
SSH public key fingerprints.
Fingerprints have an associated key fingerprint algorithm, i.e. a hash function which is used to compute the fingerprint.
Parsing/serializing fingerprint strings
The FromStr and Display impls on Fingerprint can be used to
parse and serialize fingerprints from the string format.
Example
SHA256:Nh0Me49Zh9fDw/VYUfq43IJmI1T+XrjiYONPND8GzaM
serde support
When the serde feature of this crate is enabled, this type receives impls
of Deserialize and Serialize.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sha256([u8; 32])
Fingerprints computed using SHA-256.
Sha512([u8; 64])
Fingerprints computed using SHA-512.
Implementations