#[non_exhaustive]pub enum HashAlg {
Sha256,
Sha512,
}Expand description
Hashing algorithms a.k.a. digest functions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl HashAlg
impl HashAlg
Sourcepub fn new(id: &str) -> Result<Self>
pub fn new(id: &str) -> Result<Self>
Decode elliptic curve from the given string identifier.
Supported hash algorithms
sha256sha512
Errors
Returns Error::Encoding in the event the algorithm name is not known.
Sourcepub const fn digest_size(self) -> usize
pub const fn digest_size(self) -> usize
Get the size of a digest produced by this hash function.