pub enum Marker {
CertAuthority,
Revoked,
}
Available on crate feature alloc only.
Markers associated with this host key entry.
There can only be one of these per host key entry.
This host entry’s public key is for a certificate authority’s private key
This host entry’s public key has been revoked, and should not be allowed to connect
regardless of any other entry.
Get the string form of the marker
Converts this type into a shared reference of the (usually inferred) input type.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
The associated error which can be returned from parsing.
Parses a string
s to return a value of this type.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.