pub struct OpaqueKeypairBytes {
    pub private: OpaquePrivateKeyBytes,
    pub public: OpaquePublicKeyBytes,
}
Available on crate feature alloc only.
The underlying representation of an OpaqueKeypair.

The encoded representation of an OpaqueKeypairBytes consists of the encoded representation of its OpaquePublicKeyBytes followed by the encoded representation of its OpaquePrivateKeyBytes.

Fields

private: OpaquePrivateKeyBytes

The opaque private key

public: OpaquePublicKeyBytes

The opaque public key