pub struct Comment(/* private fields */);alloc only.Expand description
SSH key comment (e.g. email address of owner)
Comments may be found in both the binary serialization of PrivateKey as well as the text
serialization of PublicKey.
The binary serialization of PrivateKey stores the comment encoded as an RFC4251
string type which can contain arbitrary binary data and does not necessarily represent valid
UTF-8. To support round trip encoding of such comments.
To support round-trip encoding of such comments, this type also supports arbitrary binary data.
Implementations
Sourceimpl Comment
impl Comment
Sourcepub fn as_str(&self) -> Result<&str, Error>
pub fn as_str(&self) -> Result<&str, Error>
Interpret the comment as a UTF-8 string.
Errors
Returns Error::CharacterEncoding in the event the underlying bytes cannot be interpreted
as valid UTF-8.
Sourcepub fn as_str_lossy(&self) -> &str
pub fn as_str_lossy(&self) -> &str
Interpret the comment as a UTF-8 string.
This is the maximal prefix of the comment which can be interpreted as valid UTF-8.