DotSsh

Struct DotSsh 

pub struct DotSsh { /* private fields */ }
Available on crate feature std only.
~/.ssh directory support (or similarly structured directories).

Implementations

Source

impl DotSsh

pub fn new() -> Option<Self>

Open ~/.ssh if the home directory can be located.

Returns None if the home directory couldn’t be located.

pub fn open(path: impl Into<PathBuf>) -> Self

Open a ~/.ssh-structured directory.

Does not verify that the directory exists or has the right file permissions.

Attempts to canonicalize the path once opened.

pub fn path(&self) -> &Path

Get the path to the ~/.ssh directory (or whatever DotSsh::open was called with).

pub fn config_path(&self) -> PathBuf

Get the path to the ~/.ssh/config configuration file. Does not check if it exists.

pub fn private_keys(&self) -> Result<impl Iterator<Item = PrivateKey>>

Iterate over the private keys in the ~/.ssh directory.

Errors

Returns Error::Io in the event of I/O errors.

pub fn private_key_with_fingerprint( &self, fingerprint: Fingerprint, ) -> Option<PrivateKey>

Find a private key whose public key has the given key fingerprint.

pub fn public_keys(&self) -> Result<impl Iterator<Item = PublicKey>>

Iterate over the public keys in the ~/.ssh directory.

Errors

Returns Error::Io in the event of I/O errors.

pub fn public_key_with_fingerprint( &self, fingerprint: Fingerprint, ) -> Option<PublicKey>

Find a public key with the given key fingerprint.

pub fn write_private_key( &self, filename: impl AsRef<Path>, key: &PrivateKey, ) -> Result<()>

Write a private key into ~/.ssh.

Errors

Returns Error::Io in the event of I/O errors.

pub fn write_public_key( &self, filename: impl AsRef<Path>, key: &PublicKey, ) -> Result<()>

Write a public key into ~/.ssh.

Errors

Returns Error::Io in the event of I/O errors.