pub struct Signature { /* private fields */ }Available on crate feature
alloc only.Expand description
Digital signature (e.g. DSA, ECDSA, Ed25519).
These are used as part of the OpenSSH certificate format to represent signatures by certificate authorities (CAs).
From OpenSSH’s PROTOCOL.certkeys specification:
Signatures are computed and encoded according to the rules defined for the CA’s public key algorithm (RFC4253 section 6.6 for ssh-rsa and ssh-dss, RFC5656 for the ECDSA types, and RFC8032 for Ed25519).
RSA signature support is implemented using the SHA2 family extensions as described in RFC8332.
Implementations
sourceimpl Signature
impl Signature
sourcepub fn new(algorithm: Algorithm, data: impl Into<Vec<u8>>) -> Result<Self>
pub fn new(algorithm: Algorithm, data: impl Into<Vec<u8>>) -> Result<Self>
Create a new signature with the given algorithm and raw signature data.
See specifications in toplevel Signature documentation for how to
format the raw signature data for a given algorithm.
Returns
Error::Lengthif the signature is not the correct length.