Enum ssh_key::Algorithm

source ·
#[non_exhaustive]
pub enum Algorithm { Dsa, Ecdsa { curve: EcdsaCurve, }, Ed25519, Rsa { hash: Option<HashAlg>, }, SkEcdsaSha2NistP256, SkEd25519, }
SSH key algorithms.

This type provides a registry of supported digital signature algorithms used for SSH keys.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Dsa

Digital Signature Algorithm



Ecdsa

Fields

curve: EcdsaCurve

Elliptic curve with which to instantiate ECDSA.

Elliptic Curve Digital Signature Algorithm



Ed25519

Ed25519



Rsa

Fields

hash: Option<HashAlg>

Hash function to use with RSASSA-PKCS#1v15 signatures as specified using RFC8332 algorithm identifiers.

If hash is set to None, then ssh-rsa is used as the algorithm name.

RSA



SkEcdsaSha2NistP256

FIDO/U2F key with ECDSA/NIST-P256 + SHA-256



SkEd25519

FIDO/U2F key with Ed25519

Implementations

source

impl Algorithm

source

pub fn new(id: &str) -> Result<Self>

Decode algorithm from the given string identifier.

Supported algorithms
  • ecdsa-sha2-nistp256
  • ecdsa-sha2-nistp384
  • ecdsa-sha2-nistp521
  • ssh-dss
  • ssh-ed25519
  • ssh-rsa
  • sk-ecdsa-sha2-nistp256@openssh.com (FIDO/U2F key)
  • sk-ssh-ed25519@openssh.com (FIDO/U2F key)
source

pub fn new_certificate(id: &str) -> Result<Self>

Decode algorithm from the given string identifier as used by the OpenSSH certificate format.

OpenSSH certificate algorithms end in *-cert-v01@openssh.com. See PROTOCOL.certkeys for more information.

Supported algorithms
  • ssh-rsa-cert-v01@openssh.com
  • ssh-dss-cert-v01@openssh.com
  • ecdsa-sha2-nistp256-cert-v01@openssh.com
  • ecdsa-sha2-nistp384-cert-v01@openssh.com
  • ecdsa-sha2-nistp521-cert-v01@openssh.com
  • ssh-ed25519-cert-v01@openssh.com
  • sk-ecdsa-sha2-nistp256-cert-v01@openssh.com (FIDO/U2F key)
  • sk-ssh-ed25519-cert-v01@openssh.com (FIDO/U2F key)
source

pub fn as_str(self) -> &'static str

Get the string identifier which corresponds to this algorithm.

source

pub fn as_certificate_str(self) -> &'static str

Get the string identifier which corresponds to the OpenSSH certificate format.

OpenSSH certificate algorithms end in *-cert-v01@openssh.com. See PROTOCOL.certkeys for more information.

source

pub fn is_dsa(self) -> bool

Is the algorithm DSA?

source

pub fn is_ecdsa(self) -> bool

Is the algorithm ECDSA?

source

pub fn is_ed25519(self) -> bool

Is the algorithm Ed25519?

source

pub fn is_rsa(self) -> bool

Is the algorithm RSA?