Enum ssh_key::private::KeypairData
source · [−]#[non_exhaustive]
pub enum KeypairData {
Dsa(DsaKeypair),
Ecdsa(EcdsaKeypair),
Ed25519(Ed25519Keypair),
Encrypted(Vec<u8>),
Rsa(RsaKeypair),
SkEcdsaSha2NistP256(SkEcdsaSha2NistP256),
SkEd25519(SkEd25519),
}Expand description
Private key data: digital signature key pairs.
SSH private keys contain pairs of public and private keys for various supported digital signature algorithms.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Dsa(DsaKeypair)
alloc only.Digital Signature Algorithm (DSA) keypair.
Ecdsa(EcdsaKeypair)
ecdsa only.ECDSA keypair.
Ed25519(Ed25519Keypair)
Ed25519 keypair.
Encrypted(Vec<u8>)
alloc only.Encrypted private key (ciphertext).
Rsa(RsaKeypair)
alloc only.RSA keypair.
SkEcdsaSha2NistP256(SkEcdsaSha2NistP256)
alloc and ecdsa only.Security Key (FIDO/U2F) using ECDSA/NIST P-256 as specified in PROTOCOL.u2f.
SkEd25519(SkEd25519)
alloc only.Security Key (FIDO/U2F) using Ed25519 as specified in PROTOCOL.u2f.
Implementations
sourceimpl KeypairData
impl KeypairData
sourcepub fn dsa(&self) -> Option<&DsaKeypair>
Available on crate feature alloc only.
pub fn dsa(&self) -> Option<&DsaKeypair>
alloc only.Get DSA keypair if this key is the correct type.
sourcepub fn ecdsa(&self) -> Option<&EcdsaKeypair>
Available on crate feature ecdsa only.
pub fn ecdsa(&self) -> Option<&EcdsaKeypair>
ecdsa only.Get ECDSA private key if this key is the correct type.
sourcepub fn ed25519(&self) -> Option<&Ed25519Keypair>
pub fn ed25519(&self) -> Option<&Ed25519Keypair>
Get Ed25519 private key if this key is the correct type.
sourcepub fn encrypted(&self) -> Option<&[u8]>
Available on crate feature alloc only.
pub fn encrypted(&self) -> Option<&[u8]>
alloc only.Get the encrypted ciphertext if this key is encrypted.
sourcepub fn rsa(&self) -> Option<&RsaKeypair>
Available on crate feature alloc only.
pub fn rsa(&self) -> Option<&RsaKeypair>
alloc only.Get RSA keypair if this key is the correct type.
sourcepub fn sk_ecdsa_p256(&self) -> Option<&SkEcdsaSha2NistP256>
Available on crate features alloc and ecdsa only.
pub fn sk_ecdsa_p256(&self) -> Option<&SkEcdsaSha2NistP256>
alloc and ecdsa only.Get FIDO/U2F ECDSA/NIST P-256 private key if this key is the correct type.
sourcepub fn sk_ed25519(&self) -> Option<&SkEd25519>
Available on crate feature alloc only.
pub fn sk_ed25519(&self) -> Option<&SkEd25519>
alloc only.Get FIDO/U2F Ed25519 private key if this key is the correct type.
sourcepub fn is_ed25519(&self) -> bool
pub fn is_ed25519(&self) -> bool
Is this key an Ed25519 key?
sourcepub fn is_encrypted(&self) -> bool
pub fn is_encrypted(&self) -> bool
Is this key encrypted?
sourcepub fn is_sk_ecdsa_p256(&self) -> bool
Available on crate features alloc and ecdsa only.
pub fn is_sk_ecdsa_p256(&self) -> bool
alloc and ecdsa only.Is this key a FIDO/U2F ECDSA/NIST P-256 key?
sourcepub fn is_sk_ed25519(&self) -> bool
Available on crate feature alloc only.
pub fn is_sk_ed25519(&self) -> bool
alloc only.Is this key a FIDO/U2F Ed25519 key?